..
      Copyright (c) 2018 NEC, Corp.
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations

================================
Command-Line Interface Reference
================================

Operations for ETSI NFV-SOL implementation
------------------------------------------

.. toctree::

  cli-etsi-vnfpkgm
  cli-etsi-vnflcm


Operations for Legacy implementation
------------------------------------

.. toctree::

  cli-legacy-vim
  cli-legacy-vnfd
  cli-legacy-vnf
  cli-legacy-vnffgd
  cli-legacy-vnffg
  cli-legacy-sfc
  cli-legacy-fc
  cli-legacy-nfp
  cli-legacy-nsd
  cli-legacy-event

.. TODO(yoshito-ito): update vnffg after fixing CLI bug:
  * https://bugs.launchpad.net/python-tackerclient/+bug/1892152
  cli-legacy-vnffg

.. TODO(yoshito-ito): add ns after confirming ns operations
  * https://bugs.launchpad.net/tacker/+bug/1892144
  cli-legacy-ns

Other operations
----------------

.. toctree::
  :maxdepth: 1

  tacker-status
